﻿--[[---------------------------------------------------------------------------

Copyright (c) 2009-2010 by Rich Cushing
All Rights Reserved

E-mail: < brillynt@gmail.com >

This file is a addon to nUI.

    nUI is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    nUI is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with nUI.  If not, see <http://www.gnu.org/licenses/>.
	
THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR 
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT 
OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT 
LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, 
DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY 
THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT 
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE 
USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

--]]---------------------------------------------------------------------------

if not nUI_InfoPanels then nUI_InfoPanels = {}; end

local CreateFrame = CreateFrame;
local MouseIsOver = MouseIsOver;

nUI_INFOMODE_GRID  = 8;
nUI_INFOPANEL_GRID = "nUI_InfoPanel_Grid";

nUI_L[nUI_INFOPANEL_GRID]	      		= "Info Panel: Grid Mode";
nUI_L[nUI_INFOPANEL_GRID.."Label"]		= "Grid";


local CreateFrame = CreateFrame;
local GetTime     = GetTime;

-------------------------------------------------------------------------------
-- default configuration for the Grid info panel

nUI_InfoPanels[nUI_INFOPANEL_GRID] =
{	
	enabled   = true,
	desc      = nUI_L[nUI_INFOPANEL_GRID],			-- player friendly name/description of the panel
	label     = nUI_L[nUI_INFOPANEL_GRID.."Label"],	-- label to use on the panel selection button face
	rotation  = nUI_INFOMODE_GRID,					-- index or position this panel appears on/in when clicking the selector button
	full_size = true;								-- this plugin requires the entire info panel port without the button bag
	
	options  =
	{
		enabled  = true,
	},
};

-------------------------------------------------------------------------------
-- master frame for the plugin

local plugin    = CreateFrame( "Frame", nUI_INFOPANEL_GRID, nUI_Dashboard.Anchor );
plugin.active   = true;

local function onGridEvent(self, event, arg1)
	
	if event == "ADDON_LOADED" and arg1 == "nUI" then
		
		if not IsAddOnLoaded( "Grid" ) then 
			LoadAddOn( "Grid" );
		end
		
		plugin.active = IsAddOnLoaded( "Grid" );

	end	
	
end

plugin:SetScript( "OnEvent", onGridEvent );
plugin:RegisterEvent( "ADDON_LOADED" );


-------------------------------------------------------------------------------

plugin.initPanel = function( container, options )

	plugin.container = container;
	plugin.options   = options;

	if options and options.enabled then
			
		plugin.setEnabled( true );
		
	end
end

-------------------------------------------------------------------------------

plugin.sizeChanged = function( scale, height, width )
	
	local options  = plugin.options;
	local G_LayoutFrame   = plugin.GridLayout_Frame;
	
	plugin.scale = scale;

	nUI_Movers:lockFrame( G_LayoutFrame, false, nil );
	
	--GridLayout:OnDisable();

	G_LayoutFrame:SetWidth( width + 10); 
	G_LayoutFrame:SetHeight( height + 10 ); 

	--GridLayout.db.profile.FrameLock = true;
	--GridLayout:UpdateTabVisibility();
	--GridLayout.db.profile.borderTexture = "None";
	--GridLayout:UpdateColor();
	--GridLayout:OnEnable();
	
	G_LayoutFrame:SetParent( plugin.container );
	G_LayoutFrame:SetPoint( "TOPLEFT", plugin.container, "TOPLEFT", 0, 0 );
	G_LayoutFrame:SetPoint( "BOTTOMRIGHT", plugin.container, "BOTTOMRIGHT", 0, 0 );
	G_LayoutFrame:SetFrameStrata( G_LayoutFrame.nUI_SavedFrameStrata );
	--G_LayoutFrame:SetBackdropBorderColor( plugin.container:GetBackdropBorderColor() );
	--G_LayoutFrame:SetBackdropColor( plugin.container:GetBackdropColor() );
	G_LayoutFrame:SetFrameLevel( 0 );

	nUI_Movers:lockFrame( G_LayoutFrame, true, nil );
			
end	

-------------------------------------------------------------------------------

plugin.setEnabled = function( enabled )

	if plugin.enabled ~= enabled then
		
		plugin.enabled = enabled;
		
		if not enabled then

			local G_LayoutFrame = plugin.GridLayout_Frame;
			
			if G_LayoutFrame.nUI_SavedParent then

				nUI_Movers:lockFrame( G_LayoutFrame, false, nil );
				
				G_LayoutFrame:SetParent( G_LayoutFrame.nUI_SavedParent );
				G_LayoutFrame:SetFrameStrata( G_LayoutFrame.nUI_SavedFrameStrata );
				--G_LayoutFrame:SetBackdropBorderColor( G_LayoutFrame.border_color );
				--G_LayoutFrame:SetBackdropColor( G_LayoutFrame.backdrop_color );

				GridLayout:OnDisable();
				
			end
		
		else

			--local G_LayoutFrame = GridLayout.frame;
			local G_LayoutFrame = _G["GridLayoutFrame"];
			
			plugin.GridLayout_Frame = G_LayoutFrame;
			
			if not G_LayoutFrame.nUI_SavedParent then
				G_LayoutFrame.nUI_SavedParent   = G_LayoutFrame:GetParent();
				G_LayoutFrame.nUI_SavedFrameStrata = G_LayoutFrame:GetFrameStrata();
				--G_LayoutFrame.nUI_SavedBackdropColor = G_LayoutFrame:GetBackdropColor();
				--G_LayoutFrame.nUI_SavedBackdropColor = G_LayoutFrame:GetBackdropColor();
			end
			
			--GridLayout:OnEnable();
			
			G_LayoutFrame:SetParent( plugin.container );
			G_LayoutFrame:SetPoint( "TOPLEFT", plugin.container, "TOPLEFT", 0, 0 );
			G_LayoutFrame:SetPoint( "BOTTOMRIGHT", plugin.container, "BOTTOMRIGHT", 0, 0 );
			G_LayoutFrame:SetFrameStrata( G_LayoutFrame.nUI_SavedFrameStrata );
			G_LayoutFrame:SetFrameLevel( 0 );
			--G_LayoutFrame:SetBackdropBorderColor( plugin.container:GetBackdropBorderColor() );
			--G_LayoutFrame:SetBackdropColor( plugin.container:GetBackdropColor() );
			--GridLayout.db.profile.FrameLock = true;
			--GridLayout:UpdateTabVisibility();

			nUI_Movers:lockFrame( G_LayoutFrame, true, nil );
			
		end				
	end			
end

-------------------------------------------------------------------------------
plugin.setSelected = function( selected )

	if selected ~= plugin.selected then

		plugin.selected = selected;
		
		if selected then
	

		else
			
			
		end
	end
end
